@@ -7,6 +7,107 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class GlmModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.GlmModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GlmModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
+class GlmPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.GlmPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GlmPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setLinkPredResultCol(self, val):
+        return self._add_param('linkPredResultCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class GlmTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.GlmTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GlmTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFamily(self, val):
+        return self._add_param('family', val)
+
+    def setFitIntercept(self, val):
+        return self._add_param('fitIntercept', val)
+
+    def setLink(self, val):
+        return self._add_param('link', val)
+
+    def setLinkPower(self, val):
+        return self._add_param('linkPower', val)
+
+    def setMaxIter(self, val):
+        return self._add_param('maxIter', val)
+
+    def setOffsetCol(self, val):
+        return self._add_param('offsetCol', val)
+
+    def setRegParam(self, val):
+        return self._add_param('regParam', val)
+
+    def setVariancePower(self, val):
+        return self._add_param('variancePower', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
+class GmmModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.clustering.GmmModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GmmModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
 class GmmPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.clustering.GmmPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -23,6 +124,15 @@ class GmmPredictBatchOp(BatchOperator):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -76,6 +186,379 @@ class GroupByBatchOp(BatchOperator):
         return self._add_param('selectClause', val)
 
 
+class HashCrossFeatureBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.feature.HashCrossFeatureBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HashCrossFeatureBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class HugeDeepWalkTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.huge.HugeDeepWalkTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeDeepWalkTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSourceCol(self, val):
+        return self._add_param('sourceCol', val)
+
+    def setTargetCol(self, val):
+        return self._add_param('targetCol', val)
+
+    def setWalkLength(self, val):
+        return self._add_param('walkLength', val)
+
+    def setWalkNum(self, val):
+        return self._add_param('walkNum', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setIsToUndigraph(self, val):
+        return self._add_param('isToUndigraph', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumCheckpoint(self, val):
+        return self._add_param('numCheckpoint', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+
+class HugeLabeledWord2VecTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.huge.HugeLabeledWord2VecTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeLabeledWord2VecTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setTypeCol(self, val):
+        return self._add_param('typeCol', val)
+
+    def setVertexCol(self, val):
+        return self._add_param('vertexCol', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumCheckpoint(self, val):
+        return self._add_param('numCheckpoint', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
+
+
+class HugeLookupBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.HugeLookupBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeLookupBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMapKeyCols(self, val):
+        return self._add_param('mapKeyCols', val)
+
+    def setMapValueCols(self, val):
+        return self._add_param('mapValueCols', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setModelStreamUpdateMethod(self, val):
+        return self._add_param('modelStreamUpdateMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class HugeMetaPath2VecTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.huge.HugeMetaPath2VecTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeMetaPath2VecTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMetaPath(self, val):
+        return self._add_param('metaPath', val)
+
+    def setSourceCol(self, val):
+        return self._add_param('sourceCol', val)
+
+    def setTargetCol(self, val):
+        return self._add_param('targetCol', val)
+
+    def setTypeCol(self, val):
+        return self._add_param('typeCol', val)
+
+    def setVertexCol(self, val):
+        return self._add_param('vertexCol', val)
+
+    def setWalkLength(self, val):
+        return self._add_param('walkLength', val)
+
+    def setWalkNum(self, val):
+        return self._add_param('walkNum', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setIsToUndigraph(self, val):
+        return self._add_param('isToUndigraph', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setMode(self, val):
+        return self._add_param('mode', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumCheckpoint(self, val):
+        return self._add_param('numCheckpoint', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+
+class HugeMultiStringIndexerPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.HugeMultiStringIndexerPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeMultiStringIndexerPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class HugeNode2VecTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.huge.HugeNode2VecTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeNode2VecTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSourceCol(self, val):
+        return self._add_param('sourceCol', val)
+
+    def setTargetCol(self, val):
+        return self._add_param('targetCol', val)
+
+    def setWalkLength(self, val):
+        return self._add_param('walkLength', val)
+
+    def setWalkNum(self, val):
+        return self._add_param('walkNum', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setIsToUndigraph(self, val):
+        return self._add_param('isToUndigraph', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumCheckpoint(self, val):
+        return self._add_param('numCheckpoint', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setP(self, val):
+        return self._add_param('p', val)
+
+    def setQ(self, val):
+        return self._add_param('q', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
+
+
+class HugeWord2VecTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.huge.HugeWord2VecTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HugeWord2VecTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setMetapathMode(self, val):
+        return self._add_param('metapathMode', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumCheckpoint(self, val):
+        return self._add_param('numCheckpoint', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
+
+
 class Id3ModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
     CLS_NAME = 'com.alibaba.alink.operator.batch.classification.Id3ModelInfoBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -100,6 +583,15 @@ class Id3PredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -178,6 +670,15 @@ class ImputerPredictBatchOp(BatchOperator):
         super(ImputerPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -221,6 +722,15 @@ class IndexToStringPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -253,6 +763,108 @@ class IntersectBatchOp(BatchOperator):
         pass
 
 
+class IsolationForestsPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class IsolationForestsTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+
+class IsolationForestsBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+
 class IsotonicRegPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.regression.IsotonicRegPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -266,6 +878,15 @@ class IsotonicRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -318,9 +939,21 @@ class ItemCfItemsPerUserRecommBatchOp(BatchOperator):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -358,6 +991,15 @@ class ItemCfRateRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -381,9 +1023,21 @@ class ItemCfSimilarItemsRecommBatchOp(BatchOperator):
     def setRecommCol(self, val):
         return self._add_param('recommCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -439,9 +1093,21 @@ class ItemCfUsersPerItemRecommBatchOp(BatchOperator):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -621,6 +1287,9 @@ class JsonValueBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputColTypes(self, val):
         return self._add_param('outputColTypes', val)
 
@@ -655,6 +1324,15 @@ class KMeansPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -703,35 +1381,6 @@ class KMeansTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
         return self._add_param('randomSeed', val)
 
 
-class KeyToValueBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.KeyToValueBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KeyToValueBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMapKeyCol(self, val):
-        return self._add_param('mapKeyCol', val)
-
-    def setMapValueCol(self, val):
-        return self._add_param('mapValueCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
 class KeywordsExtractionBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.nlp.KeywordsExtractionBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -783,6 +1432,18 @@ class KnnPredictBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -914,347 +1575,3 @@ class KvToJsonBatchOp(BatchOperator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class KvToTripleBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.KvToTripleBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToTripleBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setTripleColumnValueSchemaStr(self, val):
-        return self._add_param('tripleColumnValueSchemaStr', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KvToVectorBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.KvToVectorBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToVectorBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class LassoRegModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.LassoRegModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class LassoRegPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.LassoRegPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class LassoRegTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.LassoRegTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setLambda(self, val):
-        return self._add_param('lambda', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-
-class LdaModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.clustering.LdaModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LdaModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class LdaPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.clustering.LdaPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LdaPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class LdaPredictStreamOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.LdaPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LdaPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class LdaTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.clustering.LdaTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LdaTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setTopicNum(self, val):
-        return self._add_param('topicNum', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBeta(self, val):
-        return self._add_param('beta', val)
-
-    def setLearningDecay(self, val):
-        return self._add_param('learningDecay', val)
-
-    def setMethod(self, val):
-        return self._add_param('method', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setOnlineLearningOffset(self, val):
-        return self._add_param('onlineLearningOffset', val)
-
-    def setOptimizeDocConcentration(self, val):
-        return self._add_param('optimizeDocConcentration', val)
-
-    def setRandomSeed(self, val):
-        return self._add_param('randomSeed', val)
-
-    def setSubsamplingRate(self, val):
-        return self._add_param('subsamplingRate', val)
-
-    def setVocabSize(self, val):
-        return self._add_param('vocabSize', val)
-
-
-class LeaveKObjectOutBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.LeaveKObjectOutBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LeaveKObjectOutBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setGroupCol(self, val):
-        return self._add_param('groupCol', val)
-
-    def setObjectCol(self, val):
-        return self._add_param('objectCol', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setFraction(self, val):
-        return self._add_param('fraction', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-
-class LeaveTopKObjectOutBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.LeaveTopKObjectOutBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LeaveTopKObjectOutBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setGroupCol(self, val):
-        return self._add_param('groupCol', val)
-
-    def setObjectCol(self, val):
-        return self._add_param('objectCol', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRateCol(self, val):
-        return self._add_param('rateCol', val)
-
-    def setFraction(self, val):
-        return self._add_param('fraction', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setRateThreshold(self, val):
-        return self._add_param('rateThreshold', val)
-
-
-class LeftOuterJoinBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.sql.LeftOuterJoinBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LeftOuterJoinBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setJoinPredicate(self, val):
-        return self._add_param('joinPredicate', val)
-
-    def setSelectClause(self, val):
-        return self._add_param('selectClause', val)
-
-    def setType(self, val):
-        return self._add_param('type', val)
-
-
-class LibSvmSinkBatchOp(BaseSinkBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.sink.LibSvmSinkBatchOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LibSvmSinkBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFilePath(self, val):
-        return self._add_param('filePath', val)
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setOverwriteSink(self, val):
-        return self._add_param('overwriteSink', val)
-
-    def setStartIndex(self, val):
-        return self._add_param('startIndex', val)
-
