@@ -1,8 +1,9 @@
 from .lazy_evaluation import pipe_j_lazy_to_py_callbacks
-from ..base import BatchOperatorWrapper, BatchOperator
+from ..base import BatchOperatorWrapper
+from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
 from ...common.types.conversion.java_method_call import auto_convert_java_type
 from ...common.types.conversion.type_converters import j_value_to_py_value
-from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
+from ...common.utils.printing import print_with_title
 
 
 class WithTrainInfo(JavaObjectWrapper):
@@ -10,7 +11,7 @@ class WithTrainInfo(JavaObjectWrapper):
         return BatchOperatorWrapper(self.get_j_obj().getTrainInfoBatchOp())
 
     def lazyPrintTrainInfo(self, title=None):
-        self.lazyCollectTrainInfo(lambda d: print(title, d, sep="\n") if title is not None else print(d))
+        return self.lazyCollectTrainInfo(lambda d: print_with_title(d, title))
 
     @auto_convert_java_type
     def collectTrainInfo(self):
@@ -22,3 +23,4 @@ class WithTrainInfo(JavaObjectWrapper):
             callbacks,
             j_value_to_py_value
         )
+        return self
