@@ -80,15 +80,6 @@ class AftSurvivalRegressionModel(Model, LocalPredictable):
         super(AftSurvivalRegressionModel, self).__init__(*args, **kwargs)
         pass
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
 
 class AggLookup(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.AggLookup'
@@ -147,6 +138,15 @@ class AlsItemsPerUserRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -173,6 +173,15 @@ class AlsRateRecommender(Model, LocalPredictable):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -202,6 +211,15 @@ class AlsSimilarItemsRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -231,6 +249,15 @@ class AlsSimilarUsersRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -263,6 +290,15 @@ class AlsUsersPerItemRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -270,427 +306,6 @@ class AlsUsersPerItemRecommender(Model, LocalPredictable):
         return self._add_param('reservedCols', val)
 
 
-class BertClassificationModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.BertClassificationModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertClassificationModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertRegressionModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.BertRegressionModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertRegressionModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTextClassifier(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.BertTextClassifier'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTextClassifier, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setTextCol(self, val):
-        return self._add_param('textCol', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setBertModelName(self, val):
-        return self._add_param('bertModelName', val)
-
-    def setCheckpointFilePath(self, val):
-        return self._add_param('checkpointFilePath', val)
-
-    def setCustomConfigJson(self, val):
-        return self._add_param('customConfigJson', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setLearningRate(self, val):
-        return self._add_param('learningRate', val)
-
-    def setMaxSeqLength(self, val):
-        return self._add_param('maxSeqLength', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumEpochs(self, val):
-        return self._add_param('numEpochs', val)
-
-    def setNumFineTunedLayers(self, val):
-        return self._add_param('numFineTunedLayers', val)
-
-    def setNumPSs(self, val):
-        return self._add_param('numPSs', val)
-
-    def setNumWorkers(self, val):
-        return self._add_param('numWorkers', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPythonEnv(self, val):
-        return self._add_param('pythonEnv', val)
-
-    def setRemoveCheckpointBeforeTraining(self, val):
-        return self._add_param('removeCheckpointBeforeTraining', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTextEmbedding(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.BertTextEmbedding'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTextEmbedding, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setBertModelName(self, val):
-        return self._add_param('bertModelName', val)
-
-    def setDoLowerCase(self, val):
-        return self._add_param('doLowerCase', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setLayer(self, val):
-        return self._add_param('layer', val)
-
-    def setMaxSeqLength(self, val):
-        return self._add_param('maxSeqLength', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTextPairClassifier(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.BertTextPairClassifier'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTextPairClassifier, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setTextCol(self, val):
-        return self._add_param('textCol', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setBertModelName(self, val):
-        return self._add_param('bertModelName', val)
-
-    def setCheckpointFilePath(self, val):
-        return self._add_param('checkpointFilePath', val)
-
-    def setCustomConfigJson(self, val):
-        return self._add_param('customConfigJson', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setLearningRate(self, val):
-        return self._add_param('learningRate', val)
-
-    def setMaxSeqLength(self, val):
-        return self._add_param('maxSeqLength', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumEpochs(self, val):
-        return self._add_param('numEpochs', val)
-
-    def setNumFineTunedLayers(self, val):
-        return self._add_param('numFineTunedLayers', val)
-
-    def setNumPSs(self, val):
-        return self._add_param('numPSs', val)
-
-    def setNumWorkers(self, val):
-        return self._add_param('numWorkers', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPythonEnv(self, val):
-        return self._add_param('pythonEnv', val)
-
-    def setRemoveCheckpointBeforeTraining(self, val):
-        return self._add_param('removeCheckpointBeforeTraining', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTextPairRegressor(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.BertTextPairRegressor'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTextPairRegressor, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setTextCol(self, val):
-        return self._add_param('textCol', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setBertModelName(self, val):
-        return self._add_param('bertModelName', val)
-
-    def setCheckpointFilePath(self, val):
-        return self._add_param('checkpointFilePath', val)
-
-    def setCustomConfigJson(self, val):
-        return self._add_param('customConfigJson', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setLearningRate(self, val):
-        return self._add_param('learningRate', val)
-
-    def setMaxSeqLength(self, val):
-        return self._add_param('maxSeqLength', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumEpochs(self, val):
-        return self._add_param('numEpochs', val)
-
-    def setNumFineTunedLayers(self, val):
-        return self._add_param('numFineTunedLayers', val)
-
-    def setNumPSs(self, val):
-        return self._add_param('numPSs', val)
-
-    def setNumWorkers(self, val):
-        return self._add_param('numWorkers', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPythonEnv(self, val):
-        return self._add_param('pythonEnv', val)
-
-    def setRemoveCheckpointBeforeTraining(self, val):
-        return self._add_param('removeCheckpointBeforeTraining', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTextRegressor(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.BertTextRegressor'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTextRegressor, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setTextCol(self, val):
-        return self._add_param('textCol', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setBertModelName(self, val):
-        return self._add_param('bertModelName', val)
-
-    def setCheckpointFilePath(self, val):
-        return self._add_param('checkpointFilePath', val)
-
-    def setCustomConfigJson(self, val):
-        return self._add_param('customConfigJson', val)
-
-    def setInferBatchSize(self, val):
-        return self._add_param('inferBatchSize', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setLearningRate(self, val):
-        return self._add_param('learningRate', val)
-
-    def setMaxSeqLength(self, val):
-        return self._add_param('maxSeqLength', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumEpochs(self, val):
-        return self._add_param('numEpochs', val)
-
-    def setNumFineTunedLayers(self, val):
-        return self._add_param('numFineTunedLayers', val)
-
-    def setNumPSs(self, val):
-        return self._add_param('numPSs', val)
-
-    def setNumWorkers(self, val):
-        return self._add_param('numWorkers', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPythonEnv(self, val):
-        return self._add_param('pythonEnv', val)
-
-    def setRemoveCheckpointBeforeTraining(self, val):
-        return self._add_param('removeCheckpointBeforeTraining', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class BertTokenizer(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.BertTokenizer'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(BertTokenizer, self).__init__(*args, **kwargs)
-        pass
-
-
 class Binarizer(Transformer, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.feature.Binarizer'
     OP_TYPE = 'FUNCTION'
@@ -853,6 +468,15 @@ class Bucketizer(Transformer, LocalPredictable):
     def setLeftOpen(self, val):
         return self._add_param('leftOpen', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1316,100 +940,6 @@ class CartReg(Estimator, HasLazyPrintModelInfo):
         return self._add_param('weightCol', val)
 
 
-class CartRegEncoder(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.feature.CartRegEncoder'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CartRegEncoder, self).__init__(*args, **kwargs)
-        pass
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setCreateTreeMode(self, val):
-        return self._add_param('createTreeMode', val)
-
-    def setMaxBins(self, val):
-        return self._add_param('maxBins', val)
-
-    def setMaxDepth(self, val):
-        return self._add_param('maxDepth', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMaxMemoryInMB(self, val):
-        return self._add_param('maxMemoryInMB', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinSamplesPerLeaf(self, val):
-        return self._add_param('minSamplesPerLeaf', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-
-class CartRegEncoderModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.feature.CartRegEncoderModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CartRegEncoderModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
 class CartRegModel(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.CartRegModel'
     OP_TYPE = 'FUNCTION'
@@ -1935,14 +1465,43 @@ class DecisionTreeEncoderModel(Model, LocalPredictable):
         return self._add_param('reservedCols', val)
 
 
-class DecisionTreeRegEncoder(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.feature.DecisionTreeRegEncoder'
+class DecisionTreeRegressionModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressionModel'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DecisionTreeRegEncoder, self).__init__(*args, **kwargs)
+        super(DecisionTreeRegressionModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class DecisionTreeRegressor(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DecisionTreeRegressor, self).__init__(*args, **kwargs)
         pass
 
     def setFeatureCols(self, val):
@@ -1996,21 +1555,275 @@ class DecisionTreeRegEncoder(Estimator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setTreeType(self, val):
-        return self._add_param('treeType', val)
-
     def setWeightCol(self, val):
         return self._add_param('weightCol', val)
 
 
-class DecisionTreeRegEncoderModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.feature.DecisionTreeRegEncoderModel'
+class DocCountVectorizer(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizer'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DecisionTreeRegEncoderModel, self).__init__(*args, **kwargs)
+        super(DocCountVectorizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setFeatureType(self, val):
+        return self._add_param('featureType', val)
+
+    def setMaxDF(self, val):
+        return self._add_param('maxDF', val)
+
+    def setMinDF(self, val):
+        return self._add_param('minDF', val)
+
+    def setMinTF(self, val):
+        return self._add_param('minTF', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVocabSize(self, val):
+        return self._add_param('vocabSize', val)
+
+
+class DocCountVectorizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocCountVectorizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class DocHashCountVectorizer(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocHashCountVectorizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocHashCountVectorizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setFeatureType(self, val):
+        return self._add_param('featureType', val)
+
+    def setMinDF(self, val):
+        return self._add_param('minDF', val)
+
+    def setMinTF(self, val):
+        return self._add_param('minTF', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class DocHashCountVectorizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocHashCountVectorizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocHashCountVectorizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class EqualWidthDiscretizer(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.EqualWidthDiscretizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(EqualWidthDiscretizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setLeftOpen(self, val):
+        return self._add_param('leftOpen', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumBuckets(self, val):
+        return self._add_param('numBuckets', val)
+
+    def setNumBucketsArray(self, val):
+        return self._add_param('numBucketsArray', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class EqualWidthDiscretizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.EqualWidthDiscretizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(EqualWidthDiscretizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class FeatureHasher(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.FeatureHasher'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FeatureHasher, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class FmClassificationModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.FmClassificationModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmClassificationModel, self).__init__(*args, **kwargs)
         pass
 
     def setPredictionCol(self, val):
@@ -2028,23 +1841,153 @@ class DecisionTreeRegEncoderModel(Model, LocalPredictable):
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
 
-class DecisionTreeRegressionModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressionModel'
+
+class FmClassifier(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.FmClassifier'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DecisionTreeRegressionModel, self).__init__(*args, **kwargs)
+        super(FmClassifier, self).__init__(*args, **kwargs)
         pass
 
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setInitStdev(self, val):
+        return self._add_param('initStdev', val)
+
+    def setLambda0(self, val):
+        return self._add_param('lambda0', val)
+
+    def setLambda1(self, val):
+        return self._add_param('lambda1', val)
+
+    def setLambda2(self, val):
+        return self._add_param('lambda2', val)
+
+    def setLearnRate(self, val):
+        return self._add_param('learnRate', val)
+
+    def setMinibatchSize(self, val):
+        return self._add_param('minibatchSize', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFactor(self, val):
+        return self._add_param('numFactor', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWithIntercept(self, val):
+        return self._add_param('withIntercept', val)
+
+    def setWithLinearItem(self, val):
+        return self._add_param('withLinearItem', val)
+
+
+class FmItemsPerUserRecommender(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.FmItemsPerUserRecommender'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmItemsPerUserRecommender, self).__init__(*args, **kwargs)
+        pass
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
+    def setExcludeKnown(self, val):
+        return self._add_param('excludeKnown', val)
+
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
+    def setK(self, val):
+        return self._add_param('k', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class FmRateRecommender(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.FmRateRecommender'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmRateRecommender, self).__init__(*args, **kwargs)
+        pass
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
     def setModelStreamFilePath(self, val):
         return self._add_param('modelStreamFilePath', val)
 
