@@ -4,6 +4,73 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
+class GBRankPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.GBRankPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GBRankPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class GbdtPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.GbdtPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(GbdtPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
 class GbdtRegPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.regression.GbdtRegPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -17,6 +84,15 @@ class GbdtRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -40,6 +116,15 @@ class GeoKMeansPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -69,9 +154,21 @@ class GlmPredictStreamOp(BaseModelStreamOp):
     def setLinkPredResultCol(self, val):
         return self._add_param('linkPredResultCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
 
 class GmmPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.GmmPredictStreamOp'
@@ -89,6 +186,15 @@ class GmmPredictStreamOp(BaseModelStreamOp):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -99,6 +205,61 @@ class GmmPredictStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class HashCrossFeatureStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.HashCrossFeatureStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HashCrossFeatureStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class HopTimeWindowStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.HopTimeWindowStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HopTimeWindowStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setHopTime(self, val):
+        return self._add_param('hopTime', val)
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setWindowTime(self, val):
+        return self._add_param('windowTime', val)
+
+    def setLatency(self, val):
+        return self._add_param('latency', val)
+
+    def setPartitionCols(self, val):
+        return self._add_param('partitionCols', val)
+
+    def setWatermarkType(self, val):
+        return self._add_param('watermarkType', val)
+
+
 class Id3PredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.classification.Id3PredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -112,6 +273,15 @@ class Id3PredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -132,6 +302,15 @@ class ImputerPredictStreamOp(BaseModelStreamOp):
         super(ImputerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -155,6 +334,15 @@ class IndexToStringPredictStreamOp(BaseModelStreamOp):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -165,6 +353,38 @@ class IndexToStringPredictStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class IsolationForestsPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.outlier.IsolationForestsPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class IsotonicRegPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.regression.IsotonicRegPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -178,6 +398,15 @@ class IsotonicRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -201,9 +430,21 @@ class ItemCfItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -230,6 +471,15 @@ class ItemCfRateRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -253,9 +503,21 @@ class ItemCfSimilarItemsRecommStreamOp(BaseModelStreamOp):
     def setRecommCol(self, val):
         return self._add_param('recommCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -282,9 +544,21 @@ class ItemCfUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -444,6 +718,9 @@ class JsonValueStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputColTypes(self, val):
         return self._add_param('outputColTypes', val)
 
@@ -467,6 +744,15 @@ class KMeansPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -496,9 +782,6 @@ class KafkaSinkStreamOp(BaseSinkStreamOp):
     def setDataFormat(self, val):
         return self._add_param('dataFormat', val)
 
-    def setPluginVersion(self, val):
-        return self._add_param('pluginVersion', val)
-
     def setTopic(self, val):
         return self._add_param('topic', val)
 
@@ -525,9 +808,6 @@ class KafkaSourceStreamOp(StreamOperator):
     def setGroupId(self, val):
         return self._add_param('groupId', val)
 
-    def setPluginVersion(self, val):
-        return self._add_param('pluginVersion', val)
-
     def setStartupMode(self, val):
         return self._add_param('startupMode', val)
 
@@ -544,35 +824,6 @@ class KafkaSourceStreamOp(StreamOperator):
         return self._add_param('topicPattern', val)
 
 
-class KeyToValueStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.KeyToValueStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KeyToValueStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMapKeyCol(self, val):
-        return self._add_param('mapKeyCol', val)
-
-    def setMapValueCol(self, val):
-        return self._add_param('mapValueCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
 class KeywordsExtractionStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.KeywordsExtractionStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -775,6 +1026,15 @@ class LassoRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -785,6 +1045,41 @@ class LassoRegPredictStreamOp(BaseModelStreamOp):
         return self._add_param('vectorCol', val)
 
 
+class LdaPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.LdaPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LdaPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class LibSvmSinkStreamOp(BaseSinkStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sink.LibSvmSinkStreamOp'
     OP_TYPE = 'SINK'
@@ -841,6 +1136,15 @@ class LinearRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -864,6 +1168,15 @@ class LinearSvmPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -890,6 +1203,15 @@ class LogisticRegressionPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -903,6 +1225,47 @@ class LogisticRegressionPredictStreamOp(BaseModelStreamOp):
         return self._add_param('vectorCol', val)
 
 
+class LookupStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.LookupStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LookupStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMapKeyCols(self, val):
+        return self._add_param('mapKeyCols', val)
+
+    def setMapValueCols(self, val):
+        return self._add_param('mapValueCols', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setModelStreamUpdateMethod(self, val):
+        return self._add_param('modelStreamUpdateMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class MaxAbsScalerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.MaxAbsScalerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -913,6 +1276,15 @@ class MaxAbsScalerPredictStreamOp(BaseModelStreamOp):
         super(MaxAbsScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -930,6 +1302,15 @@ class MinMaxScalerPredictStreamOp(BaseModelStreamOp):
         super(MinMaxScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -937,6 +1318,84 @@ class MinMaxScalerPredictStreamOp(BaseModelStreamOp):
         return self._add_param('outputCols', val)
 
 
+class ModelStreamFileSinkStreamOp(BaseSinkStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.ModelStreamFileSinkStreamOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ModelStreamFileSinkStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setNumKeepModel(self, val):
+        return self._add_param('numKeepModel', val)
+
+
+class ModelStreamFileSourceStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.source.ModelStreamFileSourceStreamOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ModelStreamFileSourceStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setScanInterval(self, val):
+        return self._add_param('scanInterval', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setStartTime(self, val):
+        return self._add_param('startTime', val)
+
+
+class MultiHotPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.MultiHotPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(MultiHotPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class MultiStringIndexerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.MultiStringIndexerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -953,6 +1412,18 @@ class MultiStringIndexerPredictStreamOp(BaseModelStreamOp):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCols(self, val):
         return self._add_param('outputCols', val)
 
@@ -973,6 +1444,15 @@ class MultilayerPerceptronPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1002,6 +1482,9 @@ class NGramStreamOp(StreamOperator):
     def setN(self, val):
         return self._add_param('n', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -1022,6 +1505,15 @@ class NaiveBayesPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1048,190 +1540,14 @@ class NaiveBayesTextPredictStreamOp(BaseModelStreamOp):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
 
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class OneHotPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.OneHotPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(OneHotPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setDropLast(self, val):
-        return self._add_param('dropLast', val)
-
-    def setEncode(self, val):
-        return self._add_param('encode', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class PcaPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.PcaPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(PcaPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class PrintStreamOp(BaseSinkStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.utils.PrintStreamOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(PrintStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMaxLimit(self, val):
-        return self._add_param('maxLimit', val)
-
-    def setRefreshInterval(self, val):
-        return self._add_param('refreshInterval', val)
-
-
-class PyBinaryScalarFunctionStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryScalarFunctionStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(PyBinaryScalarFunctionStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setClassObject(self, val):
-        return self._add_param('classObject', val)
-
-    def setClassObjectType(self, val):
-        return self._add_param('classObjectType', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setResultType(self, val):
-        return self._add_param('resultType', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class PyBinaryTableFunctionStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryTableFunctionStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(PyBinaryTableFunctionStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setClassObject(self, val):
-        return self._add_param('classObject', val)
-
-    def setClassObjectType(self, val):
-        return self._add_param('classObjectType', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setResultTypes(self, val):
-        return self._add_param('resultTypes', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class QuantileDiscretizerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.QuantileDiscretizerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(QuantileDiscretizerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setDropLast(self, val):
-        return self._add_param('dropLast', val)
-
-    def setEncode(self, val):
-        return self._add_param('encode', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class RandomForestPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.RandomForestPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
@@ -1242,55 +1558,3 @@ class RandomForestPredictStreamOp(BaseModelStreamOp):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class RandomForestRegPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.RandomForestRegPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestRegPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class RandomTableSourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.RandomTableSourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomTableSourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMaxRows(self, val):
-        return self._add_param('maxRows', val)
-
-    def setNumCols(self, val):
-        return self._add_param('numCols', val)
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setOutputColConfs(self, val):
-        return self._add_param('outputColConfs', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setTimePerSample(self, val):
-        return self._add_param('timePerSample', val)
-
-    def setTimeZones(self, val):
-        return self._add_param('timeZones', val)
-
